@@ -1,59 +1,32 @@
-import uuid
-from decimal import *
+from decimal import Decimal
+
+from foqus.azure_configuration import *
+from foqus.aws_configuration import *
+from foqus.customers import create_or_update_user_apikey, create_update_project, get_user_apikey, send_email_to_admin
+from foqus.server_apis import shopify_training
+
+from ip2geotools.databases.noncommercial import DbIpCity
+
+from keras.preprocessing import image
 from multiprocessing.pool import ThreadPool, TimeoutError
 from os import listdir
 from os.path import isfile, join
 
+from PIL import Image
+
 import urllib.request
 import urllib.parse
 
-
-from PIL import Image
-from keras.preprocessing import image
-from foqus.azure_configuration import *
-from foqus.aws_configuration import *
-from foqus.configuration import *
-from foqus.customers import create_or_update_user_apikey, save_data_from_cms, create_update_project, send_email_to_admin
-
-import logging
-import coloredlogs
-from ip2geotools.databases.noncommercial import DbIpCity
-import os, time, datetime, calendar, hashlib, xlrd, csv, inspect, requests
-
-from foqus.server_apis import customer_info, shopify_training
-
-AWS_ACCESS_KEY = AWS_KEY_ID
-AWS_ACCESS_SECRET = AWS_SECRET_KEY
-
-if USE_LOG_AZURE:
-
-    from azure_storage_logging.handlers import TableStorageHandler
-    # configure the handler and add it to the logger
-    logger = logging.getLogger(__name__)
-    handler = TableStorageHandler(account_name=LOG_AZURE_ACCOUNT_NAME,
-                                  account_key=LOG_AZURE_ACCOUNT_KEY,
-                                  extra_properties=('%(hostname)s',
-                                                    '%(levelname)s'))
-    logger.setLevel(logging.DEBUG)
-    logger.addHandler(handler)
-else:
-
-    logger = logging.getLogger(__name__)
-    coloredlogs.install()
-    logger.setLevel(logging.DEBUG)
-    # create file handler which logs even debug messages
-    fh = logging.FileHandler(LOG_PATH + 'trynfit_debug.log')
-    fh.setLevel(logging.DEBUG)
-    # create console handler with a higher log level
-    ch = logging.StreamHandler()
-    ch.setLevel(logging.ERROR)
-    # create formatter and add it to the handlers
-    formatter = logging.Formatter('[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s', '%d/%b/%Y %H:%M:%S')
-    ch.setFormatter(formatter)
-    fh.setFormatter(formatter)
-    # add the handlers to logger
-    logger.addHandler(ch)
-    logger.addHandler(fh)
+import calendar
+import csv
+import datetime
+import hashlib
+import inspect
+import os
+import requests
+import time
+import uuid
+import xlrd
 
 
 class MultiTaskPool:
@@ -88,8 +61,49 @@ class MultiTaskPool:
             self.pop_thread(i)
 
 
-def update_the_database(db, filename):
+def replace_special_caractere(chaine_to_replace=''):
+    '''
+    :param chaine_to_replace: str that may contains special caracters
+    :return: str with no special caracters (all are replaced)
+    '''
+    list_caracters = [(['ê', 'ë', 'é', 'è'], 'e'), (['ç'], 'c'), (['ä', 'å', 'ã', 'à'], 'a'),
+                      (['í', 'î', 'ì', 'î', 'ï'], 'i'),
+                      (['ñ'], 'n'), (['ó', 'ò', 'ô', 'ö', 'õ', 'ø'], 'o'), (['š', 's']), (['ú', 'ù', 'û', 'ü'], 'u'),
+                      (['ý', 'ÿ'], 'y'), (['ž'], 'z'), (['œ'], 'oe'), (['æ'], 'ae'),
+                      (['*', '#', '~', '&', '´', '^', '|', '[', '(', '{', ';', '?', ':', '=', '+', '²', '%', 'µ', '$',
+                        '£', '¨', '!', ']', '}', '@', '/', "'", '"', ',', ';', '§', '<', '>', ')', '_', '-', '.', '°',
+                        "’", "́", "̀"], '')]
+    buckwalterMod = {
+        'ء': 'a', 'ا': 'a', 'إ': 'i',
+        'أ': 'a', 'آ': 'a', 'ب': 'b',
+        'ة': 't', 'ت': 't', 'ث': 'th',
+        'ج': 'j', 'ح': 'H', 'خ': 'kh',
+        'د': 'd', 'ذ': 'dh', 'ر': 'r',
+        'ز': 'z', 'س': 's', 'ش': 'ch',
+        'ص': 's', 'ض': 'dh', 'ط': 't',
+        'ظ': 'dh', 'ع': 'a', 'غ': 'gh',
+        'ف': 'f', 'ق': 'q', 'ك': 'k',
+        'ل': 'l', 'م': 'm', 'ن': 'n',
+        'ه': 'h', 'ؤ': 'o', 'و': 'w',
+        'ى': 'y', 'ئ': 'i', 'ي': 'y',
+    }
+    for charcter in chaine_to_replace:
+        if charcter in buckwalterMod.keys():
+            chaine_to_replace = chaine_to_replace.replace(charcter, buckwalterMod[charcter])
+    chaine_to_replace = chaine_to_replace.lower()
+    for caracter in chaine_to_replace:
+        for list_special in list_caracters:
+            if caracter in list_special[0]:
+                chaine_to_replace = chaine_to_replace.replace(str(caracter), str(list_special[1]))
+    return chaine_to_replace
 
+
+def update_the_database(db, filename):
+    '''
+    :param db: the database
+    :param filename: the image to move to history (pub no active any more)
+    :return: True if everything works fine elsa False
+    '''
     try:
         url = db.get_url_from_hash(hash=filename.split("/")[-1])
         db.create_history_table(table_name=filename.split('/')[-3])
@@ -97,9 +111,10 @@ def update_the_database(db, filename):
         db.delete_hash(hash=filename.split('/')[-1])
         db.delete_smilitaries(table_name=filename.split('/')[-3], url=url)
         logger.info("Successfully updated database  ")
-
+        return True
     except Exception as e:
         logger.error("Erreur updating the database ... (%s) " % e)
+        return False
 
 
 def ping(hostname="127.0.0.1", port=80):
@@ -117,6 +132,11 @@ def ping(hostname="127.0.0.1", port=80):
 
 
 def download(url, filename):
+    '''
+    :param url: url of the file to download
+    :param filename: the file name to download to
+    :return:
+    '''
     # As long as the file is opened in binary mode, both Python 2 and Python 3
     # can write response body to it without decoding.
     try:
@@ -192,7 +212,7 @@ def get_remote_file_hash(url, max_file_size=100 * 1024 * 1024):
 def image_extension(image_url):
     r = requests.head(image_url)
     if (r.headers["content-type"]):
-        return (r.headers["content-type"].split('/')[1])
+        return r.headers["content-type"].split('/')[1]
     else:
         return image_url.split('.')[-1]
 
@@ -227,7 +247,7 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
 
         logger.info("Image URL: " + url)
         if download_operation == 1:
-            db.create_client_products_table(customer_name.replace(' ', '_'))
+            db.create_client_products_table(replace_special_caractere(customer_name).replace(' ', '_'))
 
             if os.path.exists(fichier) and os.stat(fichier).st_size == 0:
                 logger.info("File exists but size is 0... Download again!")
@@ -266,13 +286,11 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
             hash_files = hash_files + filename + " "
             if USE_AZURE:
                 if fichier.split('/')[-2] == project_name:
-                    upload_folder_into_azure(
-                        local_path=path_out,
-                        directory_path=input_azure)
+                    upload_folder_into_azure(local_path=path_out, directory_path_azure=input_azure)
 
                 else:
                     upload_folder_into_azure(local_path=path_out,
-                                             directory_path=input_azure + fichier.split('/')[-2])
+                                             directory_path_azure=input_azure + fichier.split('/')[-2])
         else:
             if remove(db, resized_fichier) == 0 and delete_from_s3(
                                             output_3 + fichier.split('/')[-2] + '/' + filename) == 0:
@@ -280,7 +298,8 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
             if remove(db, fichier) == 0 and delete_from_s3(input_s3 + fichier.split('/')[-2] + '/' + filename) == 0:
                 logger.info("Obsolete ad... Removing file from Input local and S3")
 
-    data_product = db.get_product_details(customer_name.replace(' ', '_'), each_url_product, project_name)
+    data_product = db.get_product_details(replace_special_caractere(customer_name).replace(' ', '_'), each_url_product,
+                                          project_name)
 
     if data_product:
         urls_base = data_product[1]
@@ -292,7 +311,6 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
         # hash_references = list(dict.fromkeys(hash_references))
         for i in range(0, len(urls_references)-1):
             for j in range(0, len(urls_references_base)-1):
-                print(urls_references[i], urls_references_base[j])
                 if urls_references[i] == urls_references_base[j]:
                     if hash_references[i] != hash_references_base[j]:
                         # urls_base.replace(urls_references_base[j], urls_references[i])
@@ -308,102 +326,12 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
                         urls.replace(urls_references_base[j], urls_references[i])
 
     if each_url_product == '':
-        db.add_or_update_images(table_name=customer_name.replace(' ', '_'), reference=urls, urlProduit="", hash_code=hash_files,
-                                 project_name=project_name)
+        db.add_or_update_images(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
+                                reference=urls, urlProduit="", hash_code=hash_files, project_name=project_name)
     else:
-        db.add_or_update_products(table_name=customer_name.replace(' ', '_'), reference=urls, urlProduit=each_url_product,
-                                   hash_code=hash_files, project_name=project_name, update=data_product)
-
-
-# hash with the url image
-def download_or_remove_new(url, each_url_product, download_operation=1, customer_name=None, customer_type=None, db=None, path_out=None, project_name = None, count=None, rest_photos=None , itr= None , nb_iteration = None):
-    if customer_name is None or customer_type is None or db is None:
-        logger.error("Cannot download image: missing parameters")
-        return
-
-    if path_out is None:
-        path_out = INPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name
-    input_s3 = INPUT_S3 + customer_type + '/' + customer_name + '/images/' +project_name + '/'
-    input_azure = AZURE_INPUT_PATH + customer_type + "/" + customer_name + "/images/" + project_name + '/'
-    resized_path = OUTPUT_PATH + customer_type + '/' + customer_name + '/images' + project_name + '/'
-    output_3 = OUTPUT_S3 + customer_type + '/' + customer_name + '/images/'+ project_name + '/'
-
-    hash_file= str(uuid.uuid3(uuid.NAMESPACE_URL, url.split('?')[0]))
-    filename = hash_file + "." + image_extension(url)
-    fichier = path_out + '/' + filename
-    resized_fichier = resized_path + '/' + filename
-
-    logger.info("Retrieving image from URL...")
-
-    logger.info("Image URL: " + url)
-    if download_operation == 1:
-        if os.path.exists(fichier) and os.stat(fichier).st_size == 0:
-            logger.info("File exists but size is 0... Download again!")
-            download(url, fichier)
-        elif not os.path.exists(fichier):
-            logger.info("File doesn't exist... Downloading...")
-            download(url, fichier)
-        else:
-            logger.info("File exists and not empty... Ignoring download.")
-
-        if os.path.exists(fichier) and os.stat(fichier).st_size == 0:
-            logger.info("File exists but size is 0... Download again!")
-            download(url, fichier)
-        elif not os.path.exists(fichier):
-            logger.info("File doesn't exist... Downloading...")
-            download(url, fichier)
-        else:
-            logger.info("File downloaded successfully.")
-
-        if USE_AWS:
-            upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
-        retries = 0
-        while get_file_hash(fichier) != hash_file and retries < MAX_DOWNLOAD_FILE_RETRIES:
-            logger.warning("File exists but hash is incorrect... Download again!")
-            hash_file = get_remote_file_hash(url)
-            if ('.jpg' in url) or ('.JPG' in url):
-                filename = hash_file + ".jpg"
-            elif ('.png' in url) or ('.PNG' in url):
-                filename = hash_file + ".png"
-            elif ('.jpeg' in url) or ('.JPEG' in url):
-                filename = hash_file + ".jpeg"
-            else:
-                filename = hash_file
-
-
-            hash_file = get_remote_file_hash(url)
-            download(url, fichier)
-            if USE_AWS:
-                upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
-            retries += 1
-
-        if get_file_hash(fichier) != hash_file:
-            logger.error("File wasn't downloaded correctly! " + fichier)
-        else:
-            logger.info("File was successfully downloaded (hash OK) >>> File path: " + fichier)
-
-            db.add_or_update_url_hash(url=url,
-                                      hash=filename)
-
-            db.create_client_products_table(customer_name.replace(' ', '_'))
-            db.add_or_update_products(table_name=customer_name.replace(' ', '_'), reference=url, urlProduit=each_url_product, count = count, rest_photos=rest_photos, itr = itr, nb_iteration= nb_iteration)
-
-        #upload input directory in azure
-        if USE_AZURE:
-            if fichier.split('/')[-2] == project_name:
-                upload_folder_into_azure(
-                    local_path=path_out,
-                    directory_path=input_azure)
-
-            else:
-                upload_folder_into_azure(local_path=path_out,
-                                         directory_path=input_azure + fichier.split('/')[-2])
-
-    else:
-        if remove(db, resized_fichier) == 0 and delete_from_s3(output_3 + fichier.split('/')[-2]+ '/' + filename) == 0:
-            logger.info("Obsolete ad... Removing file from Output local and S3")
-        if remove(db, fichier) == 0 and delete_from_s3(input_s3 + fichier.split('/')[-2] + '/' + filename) == 0:
-            logger.info("Obsolete ad... Removing file from Input local and S3")
+        db.add_or_update_products(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
+                                  reference=urls, urlProduit=each_url_product, hash_code=hash_files,
+                                  project_name=project_name, update=data_product)
 
 
 def safe_download(url, file_path):
@@ -466,8 +394,8 @@ def resize_images(target=TARGET_RESOLUTION, customer_name=None, customer_type=No
 
     if folders != []:
         for folder in folders:
-            input_path = INPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name+ '/' + folder
-            resized_path = OUTPUT_PATH + customer_type + '/' + customer_name + '/images/'+ project_name+ '/' + folder
+            input_path = INPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name + '/' + folder
+            resized_path = OUTPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name + '/' + folder
             if not os.path.isdir(input_path):
                 try:
                     os.makedirs(input_path)
@@ -524,7 +452,7 @@ def resizing_image(image_files, input_path, target ,resized_path, resized_paths3
         except Exception as e:
             logger.error("Error when resizing image '" + im + "'..." + str(e))
     if USE_AZURE:
-        upload_folder_into_azure(local_path=resized_path,directory_path=resized_paths3.split('BACKUP/')[1])
+        upload_folder_into_azure(local_path=resized_path, directory_path_azure=resized_paths3.split('BACKUP/')[1])
     logger.info("All downloaded images are successfully resized")
 
 
@@ -548,25 +476,24 @@ def load_image(resized_filename):
         logger.error('Exception in loading image %s, error %s' %(resized_filename, e))
 
 
-def get_client_ip(request):
-    try:
-        from flask import request
-        ip = request.environ.get('HTTP_X_REAL_IP', request.remote_addr)
-    except Exception as e:
-        ip = request.environ.get('REMOTE_ADDR')
+def get_client_ip(request_client):
+    x_forwarded_for = request_client.META.get('HTTP_X_FORWARDED_FOR')
+    if x_forwarded_for:
+        ip = x_forwarded_for.split(',')[0]
+    else:
+        ip = request_client.META.get('REMOTE_ADDR')
     return ip
 
 
 def get_client_code_country(adress):
-    if adress == "":
-        code_country = ""
-    elif adress == "127.0.0.1" or "192.168.100" in adress:
-        code_country = "FR"
-    else:
+    try:
         response = DbIpCity.get(adress, api_key='free')
         code_country = response.country
-        code_country =code_country.lower()
-        logger.info(" The code country is %s" %code_country)
+        logger.info(" The code country is %s" % code_country)
+    except Exception as e:
+
+        logger.error("Cannot get The code country for address %s" % adress)
+        code_country = "FR"
     return code_country
 
 
@@ -578,7 +505,7 @@ def get_client_country(adress):
     else:
         response = DbIpCity.get(adress, api_key='free')
         country = response.city
-        logger.info(" The code country is %s" %country)
+        logger.info(" The code country is %s" % country)
     return country
 
 
@@ -619,18 +546,20 @@ def get_api_version_shopify():
     return api_version
 
 
-def excel_valid(excel_path=None, customer_name=None,customer_type= None, customer_universe= None):
+def excel_valid(excel_path=None, customer_name=None, customer_type=None, customer_universe= None):
     try:
-        if not os.path.isdir(STREAMS_PATH + customer_type + '/' + customer_name + '/detection_erreur/' + customer_universe):
+        if not os.path.isdir(STREAMS_PATH + customer_type + '/' + customer_name + '/detection_erreur/' +
+                                     customer_universe):
             try:
 
-                os.makedirs(STREAMS_PATH + customer_type + '/' + customer_name + '/detection_erreur/' + customer_universe)
+                os.makedirs(STREAMS_PATH + customer_type + '/' + customer_name + '/detection_erreur/' +
+                            customer_universe)
             except:
                 logger.error("Cannot create streams directory for customer. Please verify permissions or change "
                              "the path in your 'config.ini'")
                 pass
-        path_excel_download = STREAMS_PATH + customer_type + '/' + customer_name + '/detection_erreur/' + customer_universe + '/' + \
-                              excel_path.split('/')[-1].split('.xlsx')[0] + '.xlsx'
+        path_excel_download = STREAMS_PATH + customer_type + '/' + customer_name + '/detection_erreur/' +\
+                              customer_universe + '/' +  excel_path.split('/')[-1].split('.xlsx')[0] + '.xlsx'
         if '://' in excel_path:
             download(excel_path, path_excel_download)
 
@@ -752,19 +681,20 @@ def download_commit_db_images(url_images, url_produits):
     if url_images:
         for image in url_images:
             try:
-                download_or_remove(image['images'], "", image['status'], image["customer_name"],
-                                   image['customer_type'], db, image['path'],
-                                   image['project_name'])
+                download_or_remove(image.get('images', ''), "", image.get('status'), image.get("customer_name"),
+                                   image.get('customer_type'), db, image.get('path'), image.get('project_name'))
             except Exception as e:
                 logger.error(
                     'Error_url_images_download_commit_db_images_count %s downloading image %s continue' % (e, image))
     else:
         for product in url_produits.keys():
             try:
-                download_or_remove(url_produits[product]['images'], product, url_produits[product]['status'],
-                                   url_produits[product]["customer_name"],
-                                   url_produits[product]['customer_type'], db, url_produits[product]['path'],
-                                   url_produits[product]['project_name'])
+                download_or_remove(url_produits.get(product, {}).get('images', ''), product,
+                                   url_produits.get(product, {}).get('status'),
+                                   url_produits.get(product, {}).get("customer_name"),
+                                   url_produits.get(product, {}).get('customer_type'), db,
+                                   url_produits.get(product, {}).get('path'),
+                                   url_produits.get(product, {}).get('project_name'))
             except Exception as e:
                 logger.error('Error_url_produits_download_commit_db_images_cont %s downloading image %s continue' %
                              (e, url_produits[product]['images']))
@@ -772,6 +702,72 @@ def download_commit_db_images(url_images, url_produits):
     db.commit_db_changes()
 
 
+def get_count_product_validation(token, url_shop, plan):
+    api_version = get_api_version_shopify()
+    headers = {
+        "X-Shopify-Access-Token": token,
+        "Content-Type": "application/json"
+    }
+    count_point = "/admin/api/%s/products/count.json" % api_version
+
+    count_products = requests.get("https://{0}{1}".format(url_shop, count_point), headers=headers)
+    if count_products.status_code != 200:
+        logger.error("Error in getting info cms client shopify %s  token %s " % (url_shop, token))
+        send_email_to_admin("Errror getting cms data cron shopify",
+                            "Error_get_count_product_validation in getting info cms client shopify %s  token %s "
+                            % (url_shop, token))
+    max_images_training = db.get_plan_form_name(plan)[4]
+    count_json = json.loads(count_products.text)
+    counter = count_json.get('count', 0)
+    if counter > max_images_training or counter == 0:
+        return False
+    else:
+        return True
+
+
+def shopify_data_and_train(access_token, domain, customer_name, customer_type, user_apikey, project_name):
+    logger.info('access_token for client with domain %s is %s' % (domain, access_token))
+    headers = {
+        "X-Shopify-Access-Token": access_token,
+        "Content-Type": "application/json"
+    }
+    api_version = get_api_version_shopify()
+    endpoint = "/admin/api/%s/shop.json" % api_version
+    response = requests.get("https://{0}{1}".format(domain,
+                                                    endpoint), headers=headers)
+    if response.status_code == 200:
+        data_retreived = json.loads(response.text)
+        shop = data_retreived['shop']['domain']
+        email = data_retreived['shop']['email']
+        data_client = response.text
+
+        if customer_name and customer_type and user_apikey and project_name:
+            streams_path_product_json = STREAMS_PATH + customer_type + '/' + customer_name + \
+                                        '/similars/' + domain
+            json_file = streams_path_product_json + '/shopify_json_file_' + customer_type + '_' + customer_name + \
+                        ".json"
+            data_file = streams_path_product_json + '/data_client_file_' + customer_type + '_' + customer_name + \
+                        ".json"
+            if not os.path.exists(streams_path_product_json):
+                os.makedirs(streams_path_product_json)
+            out = open(json_file, "w")
+            out.write('{"' + shop + '":' + data_client + '}')
+            out.close()
+
+            if not os.path.exists(streams_path_product_json):
+                os.makedirs(streams_path_product_json)
+            dat_client = open(data_file, "w")
+            dat_client.write(json.dumps(data_retreived))
+            dat_client.close()
+            # TODO configure it to use AWS or AZURE
+            upload_file_into_s3(data_file, STREAMS_S3 + customer_name + '/' + customer_type + '/shopify/')
+            training_details = {}
+            create_update_project(customer_name, customer_type, project_name, 'similars', 1, project_name,
+                                  json.dumps(training_details), 1)
+            create_update_project(customer_name, customer_type, project_name, 'classification', 1,
+                                  project_name, json.dumps(training_details), 1)
+            shopify_training(user_apikey, customer_name, customer_type, project_name, domain)
+
 def get_payment_details_cms_shopify(customer_name, customer_type, domain, access_token, payment_infos):
     try:
         if payment_infos.get('status', 0) == 0:
@@ -787,95 +783,38 @@ def get_payment_details_cms_shopify(customer_name, customer_type, domain, access
             if response.status_code == 200:
                 data_retreived = json.loads(response.text)
                 for payment in data_retreived['recurring_application_charges']:
-                    if payment.get('status') == "active":
-                        payment_client = db.get_client_payment(customer_name, customer_type)
-                        db.update_client_payement(customer_name, customer_type, payment_client[11], payment.get('name'),
-                                                  1, "paypal", float(payment.get("price")) * 11)
-                        db.update_transction_id(customer_name, customer_type, payment.get("id"), payment.get('name'),
-                                                payment_client[11], 'paypal')
-                        create_or_update_user_apikey(user=customer_name, period_in_hours=8040)
-                        db.update_url_confirmation(customer_name, customer_type, 'shopify', domain, access_token, None)
-                        return True
+                    if payment.get('status') == "accepted" and str(payment.get("id")) == \
+                            payment_infos.get('transction_id', ''):
+                        activate_endpoint = "/admin/api/%s/recurring_application_charges/%s/activate.json" \
+                                            % (api_version, payment.get('id'))
+                        body_activate = {'recurring_application_charges': payment}
+                        response_activate = requests.post("https://{0}{1}".format(domain, activate_endpoint),
+                                                          json=body_activate, headers=headers)
+                        if response_activate.status_code == 200:
+                            payment_client = db.get_client_payment(customer_name, customer_type)
+                            date = (payment_client[11]).strftime("%Y-%m-%d %H:%M:%S")
+                            db.update_client_payement(customer_name, customer_type, date,
+                                                      payment.get('name'),
+                                                      1, "paypal", float(payment.get("price")) * 11)
+                            db.update_transction_id(customer_name, customer_type, str(payment.get("id")),
+                                                    payment.get('name'),
+                                                    date, 'paypal')
+                            create_or_update_user_apikey(user=customer_name, period_in_hours=8040)
+                            db.update_url_confirmation(customer_name, customer_type, 'shopify', domain, access_token,
+                                                       '')
+                            logger.info("Client shopify %s accept the payment and  it is activated %s %s"
+                                        % (domain, customer_name, customer_type))
+                            return True, get_user_apikey(customer_name)
+                        else:
+                            return False, get_user_apikey(customer_name)
+                    else:
+                        return False, get_user_apikey(customer_name)
+            return False, get_user_apikey(customer_name)
         else:
-            return True
+            return True, get_user_apikey(customer_name)
     except Exception as e:
         logger.error("Payment shopify error %s" % e)
-        return False
-
-
-def get_count_product_validation(token, url_shop, plan):
-    api_version = get_api_version_shopify()
-    headers = {
-        "X-Shopify-Access-Token": token,
-        "Content-Type": "application/json"
-    }
-    count_point = "/admin/api/%s/products/count.json" % api_version
-
-    count_products = requests.get("https://{0}{1}".format(url_shop, count_point), headers=headers)
-    if count_products.status_code != 200:
-        logger.error("Error in getting info cms client shopify %s  token %s " % (url_shop, token))
-        send_email_to_admin("Errror getting cms data cron shopify",
-                            "Error_get_count_product_validation in getting info cms client shopify %s  token %s " % (url_shop, token))
-    max_images_training = db.get_plan_form_name(plan)[4]
-    count_json = json.loads(count_products.text)
-    counter = count_json.get('count', 0)
-    if counter > max_images_training or counter == 0:
-        return False
-    else:
-        return True
-
-
-def shopify_data_and_train(access_token, domain):
-    logger.info('access_token for client with domain %s is %s' % (domain, access_token))
-    headers = {
-        "X-Shopify-Access-Token": access_token,
-        "Content-Type": "application/json"
-    }
-    api_version = get_api_version_shopify()
-    endpoint = "/admin/api/%s/shop.json" % api_version
-    response = requests.get("https://{0}{1}".format(domain,
-                                                    endpoint), headers=headers)
-    if response.status_code == 200:
-        data_retreived = json.loads(response.text)
-        lang = data_retreived['shop']['primary_locale']
-        shop = data_retreived['shop']['domain']
-        email = data_retreived['shop']['email']
-        data_client = response.text
-        payload = {
-
-            "customer_email": email
-
-        }
-        customer_information = customer_info(email)
-
-        json_data = json.loads(customer_information['data'].replace("'", '"'))
-        if "customer_name" in json_data.keys() and "customer_type" in json_data.keys() and "api_key" in json_data.keys():
-            customer_name = json_data['customer_name']
-            customer_type = json_data['customer_type']
-            project_name = str((str(shop).split("."))[0])
-            user_apikey = json_data['api_key']
-            streams_path_product_json = STREAMS_PATH + customer_type + '/' + customer_name + \
-                                        '/similars/' + domain
-            json_file = streams_path_product_json + '/shopify_json_file_' + customer_type + '_' + customer_name + \
-                        ".json"
-            data_file = streams_path_product_json + '/data_client_file_' + customer_type + '_' + customer_name + \
-                        ".json"
-            if not os.path.exists(streams_path_product_json):
-                os.makedirs(streams_path_product_json)
-            out = open(json_file, "w")
-            out.write('{"' + shop + '":' + data_client + '}')
-            out.close()
-            # TODO configure it to use AWS or AZURE
-            upload_file_into_s3(data_file, STREAMS_S3 + '/' + customer_name + '/' + customer_type  +'/shopify/')
-            save_data_from_cms(customer_name, customer_type, project_name, 'shopify', 'https://' + domain,
-                               access_token)
-            training_details = {}
-            create_update_project(customer_name, customer_type, project_name, 'similars', 1, project_name,
-                                  json.dumps(training_details), 1)
-            create_update_project(customer_name, customer_type, project_name, 'classification', 1,
-                                  project_name, json.dumps(training_details), 1)
-            shopify_training(user_apikey, customer_name, customer_type, project_name, domain)
-
+        return False, get_user_apikey(customer_name)
 
 def count_product(token, url_shop):
     api_version = get_api_version_shopify()
