@@ -1,4 +1,5 @@
-import os, socket
+import os
+import socket
 
 ENABLE_LOG_TRACES = os.environ.get('ENABLE_LOG_TRACES')
 
@@ -148,4 +149,15 @@ ALLOWED_REQUESTS_FREE= int(os.environ.get('ALLOWED_REQUESTS_FREE'))
 ALLOWED_REQUESTS_PRO= int(os.environ.get('ALLOWED_REQUESTS_PRO'))
 ALLOWED_REQUESTS_STANDARD= int(os.environ.get('ALLOWED_REQUESTS_STANDARD'))
 ALLOWED_REQUESTS_PREMIUM= int(os.environ.get('ALLOWED_REQUESTS_PREMIUM'))
-ALLOWED_REQUESTS_PLATINUM= int(os.environ.get('ALLOWED_REQUESTS_PLATINUM'))
\ No newline at end of file
+ALLOWED_REQUESTS_PLATINUM= int(os.environ.get('ALLOWED_REQUESTS_PLATINUM'))
+
+
+# Tables_Database
+STATUS_PROJECT_TABLE = os.environ.get('STATUS_PROJECT_TABLE')
+CMS_TABLE = os.environ.get('CMS_TABLE')
+HISTORY_SEARCH_TABLE = os.environ.get('HISTORY_SEARCH_TABLE')
+REVIEW_TABLE = os.environ.get('REVIEW_TABLE')
+PAYMENT_INFO = os.environ.get('PAYMENT_INFO')
+PAYMENT_TABLE = os.environ.get('PAYMENT_TABLE')
+PLAN_TABLE = os.environ.get('PLAN_TABLE')
+TVA_TABLE = os.environ.get('TVA_TABLE')
\ No newline at end of file
